@@ -26,19 +26,24 @@ class Post(models.Model):
     slug = models.SlugField(_(u'Slug'), max_length=255)
     text = models.TextField(_(u'Text'))
     tags = TagField()
-    image = models.ImageField(_(u'Image'), upload_to='images/posts', blank=True)
+    image = models.ImageField(_(u'Image'), upload_to='images/posts',
+                              blank=True)
     hits = models.IntegerField(_(u'Hits'), blank=True, default=1)
     creation_date = models.DateTimeField(_(u'Creation date'))
     user = models.ForeignKey(User, related_name="post_from")
-    highlighted =  models.BooleanField(_('Highlighted'), blank=True)
+    highlighted =  models.BooleanField(_(u'Highlighted'), blank=True)
     status =  models.BooleanField(_(u'Status'), default=True)
-    thread_id = models.CharField(_(u'Disqus thread id'), max_length=32, blank=True) # DISQUS
-    lang = models.CharField(_(u'Language of the post'), max_length=32, blank=True, null=True)
+    thread_id = models.CharField(_(u'Disqus thread id'), max_length=32,
+                                 blank=True) # DISQUS
+    lang = models.CharField(_(u'Language of the post'), max_length=32,
+                            blank=True, null=True)
 
     if "rgallery" in conf.INSTALLED_APPS:
         from rgallery.models import Photo, Video
-        photo = models.ManyToManyField(Photo, related_name="photo", blank=True, null=True)
-        video = models.ManyToManyField(Video, related_name="myvideo", blank=True, null=True)
+        photo = models.ManyToManyField(Photo, related_name="photo",
+                                       blank=True, null=True)
+        video = models.ManyToManyField(Video, related_name="myvideo",
+                                       blank=True, null=True)
 
     def set_tags(self, tags):
         Tag.objects.update_tags(self, tags)
