@@ -22,7 +22,7 @@ from disqusapi import Paginator
 from django.http import HttpResponse
 
 class MetaSidebar():
-    """Clase de la cual heredan las demas (para sideber por ejemplo)"""
+    """ Metaclass """
 
     def __init__(self):
         pass
